/* jshint node:true */
module.exports = function (grunt) {
    'use strict';

    grunt.initConfig({
        // Gets the package vars
        pkg: grunt.file.readJSON('package.json'),
        // Generate POT files.
        makepot: {
            dist: {
                options: {
                    type: 'wp-plugin',
                    potHeaders: {
                        'report-msgid-bugs-to': 'https://wordpress.org/support/plugin/woocommerce-darwin-pricing-integration',
                        'language-team': 'LANGUAGE <EMAIL@ADDRESS>'
                    }
                }
            }
        },
        // Check textdomain errors.
        checktextdomain: {
            options: {
                text_domain: '<%= pkg.name %>',
                keywords: [
                    '__:1,2d',
                    '_e:1,2d',
                    '_x:1,2c,3d',
                    'esc_html__:1,2d',
                    'esc_html_e:1,2d',
                    'esc_html_x:1,2c,3d',
                    'esc_attr__:1,2d',
                    'esc_attr_e:1,2d',
                    'esc_attr_x:1,2c,3d',
                    '_ex:1,2c,3d',
                    '_n:1,2,4d',
                    '_nx:1,2,4c,5d',
                    '_n_noop:1,2,3d',
                    '_nx_noop:1,2,3c,4d'
                ]
            },
            files: {
                src: [
                    '**/*.php', // Include all files
                    '!node_modules/**' // Exclude node_modules/
                ],
                expand: true
            }
        },
        // Create zip file.
        compress: {
            main: {
                options: {
                    archive: 'woocommerce-darwin-pricing-integration.zip'
                },
                files: [
                    {src: ['*', '!*.zip'], filter: 'isFile'},
                    {src: ['includes/*'], filter: 'isFile'},
                    {src: ['languages/*'], filter: 'isFile'},
                ]
            }
        }
    });

    // Load NPM tasks to be used here
    grunt.loadNpmTasks('grunt-wp-i18n');
    grunt.loadNpmTasks('grunt-checktextdomain');
    grunt.loadNpmTasks('grunt-contrib-compress');

    grunt.registerTask('build', 'Build WordPress plugin.', function () {
        grunt.task.run('makepot', 'checktextdomain', 'compress');
    });
};
